@@ -23,7 +23,7 @@ def get_statistic(url_name: str, platform: Optional[Platform] = Platform.pc) ->
     """
     res = requests.get(
         API_BASE_URL + f"/items/{url_name}/statistics",
-        headers={"Platform": platform},
+        headers={"Platform": platform.value},
     )
     check_wm_response(res)
     payload = res.json()["payload"]
